#
# spec file for package gnome-code-assistance
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2013 Dominique Leuenberger, Amsterdam, The Netherlands.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gnome-code-assistance
Version:        3.16.1
Release:        3.1
Summary:        Code Assistance Service for Code Editors
License:        GPL-3.0+
Group:          Development/
Url:            https://git.gnome.org/browse/gnome-code-assistance
Source:         http://download.gnome.org/sources/gnome-code-assistance/3.16/%{name}-%{version}.tar.xz
# Generic build dependencies
BuildRequires:  pkgconfig(gio-2.0)
# Python backend
BuildRequires:  dbus-1-python3
BuildRequires:  python3
BuildRequires:  python3-gobject
# C backend
%ifnarch ppc
BuildRequires:  llvm-devel
%endif
# Ruby backend
BuildRequires:  ruby >= 2.0
BuildRequires:  rubygem(ruby-dbus)
# GJS Backend
BuildRequires:  gjs
# Vala backend
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gio-2.0) >= 2.36
BuildRequires:  pkgconfig(glib-2.0) >= 2.36
BuildRequires:  pkgconfig(gobject-2.0) >= 2.36
BuildRequires:  pkgconfig(libvala-0.32)
BuildRequires:  pkgconfig(vapigen)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%glib2_gsettings_schema_requires

%description
gnome-code-assistance is a project which aims to provide common code assistance
services for code editors (simple editors as well as IDEs). It is an effort to
provide a centralized code-assistance as a service for the GNOME platform
instead of having every editor implement their own solution.

%prep
%setup -q

%build
%configure \
%ifnarch ppc
  --enable-c       \
%endif
  --enable-python  \
  --enable-ruby    \
  --enable-css     \
  --enable-js      \
  --enable-xml     \
  --enable-sh      \
  --enable-vala
make %{?_smp_mflags}

%install
%make_install

%post
%glib2_gsettings_schema_post

%postun
%glib2_gsettings_schema_postun

%files
%defattr(-,root,root)
%doc ChangeLog README COPYING
%{_datadir}/dbus-1/services/org.gnome.CodeAssist.v1.sh.service
%{_datadir}/glib-2.0/schemas/org.gnome.codeassistance.gschema.xml
%{_libexecdir}/%{name}/
%{_datadir}/dbus-1/services/org.gnome.CodeAssist.v1.*.service

%changelog
* Tue Jul  5 2016 zaitor@opensuse.org
- Update to version 3.16.1:
  + Fix compatibility with sass 3.4.22.
  + Support vala 0.34.
  + Fix crash when pylint is not available.
  + Update javascript dependencies.
- Stop passing sed, libvala-0.32 is now supported by upstream.
- Drop gca-python-fix-crash-when-missing-pylint.patch: Fixed
  upstream.
* Wed Mar 30 2016 zaitor@opensuse.org
- Prepare for libvala-0.32 via sed replacement.
- Following above change, replace pkgconfig(libvala-0.30) for
  pkgconfig(libvala-0.32) BuildRequires.
- Add gca-python-fix-crash-when-missing-pylint.patch: Fix crash
  when pylint is not available. Patch from upstream git.
* Wed Aug 19 2015 zaitor@opensuse.org
- Prepare for libvala-0.30 via sed replacement.
- Following above change, replace pkgconfig(libvala-0.28) for
  pkgconfig(libvala-0.30) BuildRequires.
* Thu Apr 30 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Update sass.
  + Add jshint support.
- Drop gnome-code-assistance-vala-0.28.patch: Fixed upstream.
* Thu Feb  5 2015 dimstar@opensuse.org
- Add gnome-code-assistance-vala-0.28.patch: Add support for
  Vala 0.28 branch.
- Add libtool BuildRequires and call to autoreconf, as above patch
  touches the build system.
- Replace pkgconfig(libvala-0.26) BuildRequires with
  pkgconfig(libvala-0.28).
* Mon Feb  2 2015 zaitor@opensuse.org
- Disable c-backend (llvm) for PPC: llvm-devel BuildRequires is not
  available on PPC. Doing this via conditional %%ifnarch.
* Thu Dec  4 2014 zaitor@opensuse.org
- Update to version 3.14.0:
  + Improvements in the C and Vala backends.
  + gnome-code-assistance now uses the same versions as GNOME's.
- Stop adding libvala-0.26 via sed in spec, no longer needed, fixed
  upstream.
* Mon Sep 29 2014 dimstar@opensuse.org
- Use vala 0.26 with GNOME 3.14:
  + Replace pkgconfig(libvala-0.24) BuildRequires with
    pkgconfig(libvala-0.26).
  + Use sed to add libvala-0.26 as supported vala version to
    configure.
* Tue Sep  9 2014 mrueckert@suse.de
- Fix buildrequires for the ruby support:
  - ruby(abi) is no longer numerical. Use versioned ruby
    BuildRequires.
  - Use rubygem(ruby-dbus) instead of rubygem-ruby-dbus.
* Wed Mar 26 2014 zaitor@opensuse.org
- Update to version 0.3.1:
  + Improvements in backends.
  + Added unit tests.
  + Lots of bugfixes.
* Fri Feb 14 2014 zaitor@opensuse.org
- Enable the vala backend as we have the required vala version now,
  and therefore "activate" pkgconfig(gobject-2.0),
  pkgconfig(glib-2.0), pkgconfig(gio-2.0), pkgconfig(gee-0.8),
  pkgconfig(libvala-0.24) and add pkgconfig(vapigen)
  BuildRequires and pass --enable-vala to configure.
* Fri Feb 14 2014 zaitor@opensuse.org
- Exchange ruby20 for ruby(abi) BuildRequires, will save us trouble
  on future updates of ruby.
* Tue Dec 17 2013 dimstar@opensuse.org
- Initial package, version 0.3.0.
